# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.audience_count_only import AudienceCountOnly
from ..types.delete_audience_response import DeleteAudienceResponse
from .raw_client import AsyncRawAudiencesClient, RawAudiencesClient
from .types.audiences_get_response import AudiencesGetResponse

if typing.TYPE_CHECKING:
    from .contacts.client import AsyncContactsClient, ContactsClient
# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class AudiencesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawAudiencesClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._contacts: typing.Optional[ContactsClient] = None

    @property
    def with_raw_response(self) -> RawAudiencesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawAudiencesClient
        """
        return self._raw_client

    def get(
        self,
        *,
        id: str,
        page: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudiencesGetResponse:
        """
        Retrieve an audience by ID with optional pagination.

        Parameters
        ----------
        id : str
            Audience ID. This identifier is a string that always begins with the prefix `aud_`, for example: `aud_abc123`.

        page : typing.Optional[int]
            Page number. If provided with or without limit, returns paginated contacts.

        limit : typing.Optional[int]
            Items per page. If provided with or without page, returns paginated contacts.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudiencesGetResponse
            Successfully retrieved audience.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.audiences.get(
            id="aud_abc123",
        )
        """
        _response = self._raw_client.get(id=id, page=page, limit=limit, request_options=request_options)
        return _response.data

    def create(
        self,
        *,
        name: str,
        description: typing.Optional[str] = OMIT,
        contacts: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudienceCountOnly:
        """
        Create a new audience with optional initial contacts. Phone numbers that don't exist will be auto-created as contacts.

        Parameters
        ----------
        name : str
            Audience name.

        description : typing.Optional[str]
            Audience description.

        contacts : typing.Optional[typing.Sequence[str]]
            Optional array of phone numbers (E.164 format) or contact IDs.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudienceCountOnly
            Successfully created the audience.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.audiences.create(
            name="Marketing Campaign Q1",
            description="Contacts for Q1 marketing push",
        )
        """
        _response = self._raw_client.create(
            name=name, description=description, contacts=contacts, request_options=request_options
        )
        return _response.data

    def delete(self, *, id: str, request_options: typing.Optional[RequestOptions] = None) -> DeleteAudienceResponse:
        """
        Permanently delete an audience and all its contact associations.

        Note: This will NOT delete the contacts themselves, only the audience and its memberships.

        Parameters
        ----------
        id : str
            Audience ID. This identifier is a string that always begins with the prefix `aud_`, for example: `aud_abc123`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteAudienceResponse
            Successfully deleted the audience.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.audiences.delete(
            id="aud_abc123",
        )
        """
        _response = self._raw_client.delete(id=id, request_options=request_options)
        return _response.data

    def update(
        self,
        *,
        id: str,
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudienceCountOnly:
        """
        Update audience metadata. This endpoint does NOT modify contacts.

        To add or remove contacts, use the [Add Contacts](/api-reference/audiences/add-contacts) or [Remove Contacts](/api-reference/audiences/remove-contacts) endpoints.

        Parameters
        ----------
        id : str
            Audience ID to update. This identifier is a string that always begins with the prefix `aud_`, for example: `aud_abc123`.

        name : typing.Optional[str]
            New audience name.

        description : typing.Optional[str]
            New audience description.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudienceCountOnly
            Successfully updated the audience.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.audiences.update(
            id="aud_abc123",
            name="Updated Audience Name",
            description="New description",
        )
        """
        _response = self._raw_client.update(id=id, name=name, description=description, request_options=request_options)
        return _response.data

    @property
    def contacts(self):
        if self._contacts is None:
            from .contacts.client import ContactsClient  # noqa: E402

            self._contacts = ContactsClient(client_wrapper=self._client_wrapper)
        return self._contacts


class AsyncAudiencesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawAudiencesClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._contacts: typing.Optional[AsyncContactsClient] = None

    @property
    def with_raw_response(self) -> AsyncRawAudiencesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawAudiencesClient
        """
        return self._raw_client

    async def get(
        self,
        *,
        id: str,
        page: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudiencesGetResponse:
        """
        Retrieve an audience by ID with optional pagination.

        Parameters
        ----------
        id : str
            Audience ID. This identifier is a string that always begins with the prefix `aud_`, for example: `aud_abc123`.

        page : typing.Optional[int]
            Page number. If provided with or without limit, returns paginated contacts.

        limit : typing.Optional[int]
            Items per page. If provided with or without page, returns paginated contacts.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudiencesGetResponse
            Successfully retrieved audience.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.audiences.get(
                id="aud_abc123",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id=id, page=page, limit=limit, request_options=request_options)
        return _response.data

    async def create(
        self,
        *,
        name: str,
        description: typing.Optional[str] = OMIT,
        contacts: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudienceCountOnly:
        """
        Create a new audience with optional initial contacts. Phone numbers that don't exist will be auto-created as contacts.

        Parameters
        ----------
        name : str
            Audience name.

        description : typing.Optional[str]
            Audience description.

        contacts : typing.Optional[typing.Sequence[str]]
            Optional array of phone numbers (E.164 format) or contact IDs.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudienceCountOnly
            Successfully created the audience.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.audiences.create(
                name="Marketing Campaign Q1",
                description="Contacts for Q1 marketing push",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            name=name, description=description, contacts=contacts, request_options=request_options
        )
        return _response.data

    async def delete(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteAudienceResponse:
        """
        Permanently delete an audience and all its contact associations.

        Note: This will NOT delete the contacts themselves, only the audience and its memberships.

        Parameters
        ----------
        id : str
            Audience ID. This identifier is a string that always begins with the prefix `aud_`, for example: `aud_abc123`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteAudienceResponse
            Successfully deleted the audience.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.audiences.delete(
                id="aud_abc123",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id=id, request_options=request_options)
        return _response.data

    async def update(
        self,
        *,
        id: str,
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudienceCountOnly:
        """
        Update audience metadata. This endpoint does NOT modify contacts.

        To add or remove contacts, use the [Add Contacts](/api-reference/audiences/add-contacts) or [Remove Contacts](/api-reference/audiences/remove-contacts) endpoints.

        Parameters
        ----------
        id : str
            Audience ID to update. This identifier is a string that always begins with the prefix `aud_`, for example: `aud_abc123`.

        name : typing.Optional[str]
            New audience name.

        description : typing.Optional[str]
            New audience description.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudienceCountOnly
            Successfully updated the audience.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.audiences.update(
                id="aud_abc123",
                name="Updated Audience Name",
                description="New description",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            id=id, name=name, description=description, request_options=request_options
        )
        return _response.data

    @property
    def contacts(self):
        if self._contacts is None:
            from .contacts.client import AsyncContactsClient  # noqa: E402

            self._contacts = AsyncContactsClient(client_wrapper=self._client_wrapper)
        return self._contacts



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .dlc_campaign_use_case_enum import DlcCampaignUseCaseEnum
from .sub_use_case_enum import SubUseCaseEnum


class AutofillDlcResponseUseCase(UniversalBaseModel):
    """
    Use case for the campaign.
    """

    sub: typing.Optional[typing.List[SubUseCaseEnum]] = pydantic.Field(default=None)
    """
    Sub-use case categories.
    """

    value: typing.Optional[DlcCampaignUseCaseEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.refreshed_file import RefreshedFile
from ...types.upload_results import UploadResults
from .raw_client import AsyncRawFileClient, RawFileClient
from .types.upload_file_options import UploadFileOptions

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class FileClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawFileClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawFileClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawFileClient
        """
        return self._raw_client

    def upload(
        self,
        *,
        content_type: str,
        size: int,
        name: typing.Optional[str] = OMIT,
        options: typing.Optional[UploadFileOptions] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UploadResults:
        """
        Generate presigned URLs that let you upload files directly to our storage and allow your users to download them securely.

        Parameters
        ----------
        content_type : str
            MIME type of your file. <br>

            Supported file types:
            - Audio: mp3, mp4, mpeg, ogg, aac, webm, wav, 3gpp, amr
            - Video: mp4, mpeg, quicktime, webm, 3gpp, H.264, m4v
            - Image: jpeg, png, gif, bmp, tiff, webp
            - Documents: pdf, csv, rtf, calendar, vcard

        size : int
            Size of your file in bytes. Should be less than 100 MB.

        name : typing.Optional[str]
            Name of your file.

        options : typing.Optional[UploadFileOptions]
            Additional configurations for your file.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UploadResults
            Successfully uploaded the file.

        Examples
        --------
        from rcs import Pinnacle
        from rcs.tools.file import DownloadOptions, UploadFileOptions

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.tools.file.upload(
            content_type="image/jpeg",
            size=1024,
            name="test.jpg",
            options=UploadFileOptions(
                delete_at="2025-12-31T23:59:59Z",
                download=DownloadOptions(
                    expires_at="2025-06-30T12:00:00.000Z",
                ),
            ),
        )
        """
        _response = self._raw_client.upload(
            content_type=content_type, size=size, name=name, options=options, request_options=request_options
        )
        return _response.data

    def refresh(
        self, *, urls: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[RefreshedFile]:
        """
        Refresh expiring presigned URLs for Pinnacle-hosted files to extend their access time.

        <Callout type="info">
          This only works for presigned download URLs. At this moment, you cannot refresh a presigned upload URL, generate a new one instead.
        </Callout>

        Parameters
        ----------
        urls : typing.Sequence[str]
            Array of file URLs to refresh for extended access. Provided URLs must be presigned URLs (i.e. `https://server.trypinnacle.app/storage/v1/object/sign/...`). Invalid or external URLs will be returned unchanged in the response.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[RefreshedFile]
            Successfully refreshed file URLs.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.tools.file.refresh(
            urls=[
                "https://server.trypinnacle.app/storage/v1/object/sign/vault/3/test.jpg?token=oldtoken",
                "https://server.trypinnacle.app/storage/v1/object/sign/vault/3/document.pdf?token=oldtoken2",
                "invalid/url",
                "https://google.com",
            ],
        )
        """
        _response = self._raw_client.refresh(urls=urls, request_options=request_options)
        return _response.data


class AsyncFileClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawFileClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawFileClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawFileClient
        """
        return self._raw_client

    async def upload(
        self,
        *,
        content_type: str,
        size: int,
        name: typing.Optional[str] = OMIT,
        options: typing.Optional[UploadFileOptions] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UploadResults:
        """
        Generate presigned URLs that let you upload files directly to our storage and allow your users to download them securely.

        Parameters
        ----------
        content_type : str
            MIME type of your file. <br>

            Supported file types:
            - Audio: mp3, mp4, mpeg, ogg, aac, webm, wav, 3gpp, amr
            - Video: mp4, mpeg, quicktime, webm, 3gpp, H.264, m4v
            - Image: jpeg, png, gif, bmp, tiff, webp
            - Documents: pdf, csv, rtf, calendar, vcard

        size : int
            Size of your file in bytes. Should be less than 100 MB.

        name : typing.Optional[str]
            Name of your file.

        options : typing.Optional[UploadFileOptions]
            Additional configurations for your file.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UploadResults
            Successfully uploaded the file.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle
        from rcs.tools.file import DownloadOptions, UploadFileOptions

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tools.file.upload(
                content_type="image/jpeg",
                size=1024,
                name="test.jpg",
                options=UploadFileOptions(
                    delete_at="2025-12-31T23:59:59Z",
                    download=DownloadOptions(
                        expires_at="2025-06-30T12:00:00.000Z",
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.upload(
            content_type=content_type, size=size, name=name, options=options, request_options=request_options
        )
        return _response.data

    async def refresh(
        self, *, urls: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[RefreshedFile]:
        """
        Refresh expiring presigned URLs for Pinnacle-hosted files to extend their access time.

        <Callout type="info">
          This only works for presigned download URLs. At this moment, you cannot refresh a presigned upload URL, generate a new one instead.
        </Callout>

        Parameters
        ----------
        urls : typing.Sequence[str]
            Array of file URLs to refresh for extended access. Provided URLs must be presigned URLs (i.e. `https://server.trypinnacle.app/storage/v1/object/sign/...`). Invalid or external URLs will be returned unchanged in the response.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[RefreshedFile]
            Successfully refreshed file URLs.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tools.file.refresh(
                urls=[
                    "https://server.trypinnacle.app/storage/v1/object/sign/vault/3/test.jpg?token=oldtoken",
                    "https://server.trypinnacle.app/storage/v1/object/sign/vault/3/document.pdf?token=oldtoken2",
                    "invalid/url",
                    "https://google.com",
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.refresh(urls=urls, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class PhoneNumberRegion(UniversalBaseModel):
    """
    Geographic and routing information for the phone number.
    """

    country: str = pydantic.Field()
    """
    Two-letter country code where the number is registered.
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    State or province code applicable to local numbers.
    """

    city: typing.Optional[str] = pydantic.Field(default=None)
    """
    Primary city or metropolitan area served by the number.
    """

    rate_center: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="rateCenter")] = pydantic.Field(
        default=None
    )
    """
    Telecommunications rate center used for call routing and billing,
    defining local calling area boundaries.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....core.serialization import FieldMetadata


class RcsCampaignTraffic(UniversalBaseModel):
    monthly_website: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="monthlyWebsite")] = (
        pydantic.Field(default=None)
    )
    """
    Estimated monthly website visitors.
    """

    monthly_rcs_estimate: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="monthlyRcsEstimate")
    ] = pydantic.Field(default=None)
    """
    Estimated monthly RCS messages sent.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

RcsCampaignUseCaseEnum = typing.Union[
    typing.Literal[
        "ENTERTAINMENT",
        "SHOPPING_AND_RETAIL",
        "GAMES",
        "NEWS",
        "HEALTH",
        "UTILITIES",
        "FINANCE",
        "SPORTS",
        "SOCIAL",
        "FOOD_AND_BEVERAGE",
        "UNCATEGORIZED",
        "TRAVEL",
        "PRODUCTIVITY",
        "OTHER",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .sms_validation_response_segments_gsm_7 import SmsValidationResponseSegmentsGsm7
from .sms_validation_response_segments_utf_16 import SmsValidationResponseSegmentsUtf16


class SmsValidationResponseSegments(UniversalBaseModel):
    """
    Details about how the SMS content would be segmented for delivery.
    """

    gsm_7: typing_extensions.Annotated[SmsValidationResponseSegmentsGsm7, FieldMetadata(alias="gsm7")] = (
        pydantic.Field()
    )
    """
    Segmentation details when your message is encoded with GSM-7.
    """

    utf_16: typing_extensions.Annotated[SmsValidationResponseSegmentsUtf16, FieldMetadata(alias="utf16")] = (
        pydantic.Field()
    )
    """
    Segmentation details when your message is encoded with UTF-16.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ReactMessageOptions(UniversalBaseModel):
    force: typing.Optional[bool] = pydantic.Field(default=None)
    """
    By default, only messages sent with the `options.tracking` field can be precisely reacted to. <br>
    
    Set `options.force` to true to bypass this restriction (may react to a different message). <br>
    
    For MMS and RCS, only messages containing text can be tracked. Otherwise, `options.force` is ignored.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .user_event_conversation import UserEventConversation


class UserEvent(UniversalBaseModel):
    """
    Represents an event triggered by a user such as when they start typing.
    """

    type: typing.Literal["USER.TYPING"] = pydantic.Field(default="USER.TYPING")
    """
    Type of user event.
    """

    started_at: typing_extensions.Annotated[str, FieldMetadata(alias="startedAt")] = pydantic.Field()
    """
    Timestamp when the user event started in ISO 8601 format.
    """

    conversation: UserEventConversation = pydantic.Field()
    """
    Conversation metadata containing the conversation ID, sender, and recipient information.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .campaign_enum import CampaignEnum


class CampaignQuery(UniversalBaseModel):
    """
    Information about the campaign associated with a conversation
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the campaign. This identifier is a string that begins with the prefix: 
    - TOLL_FREE: `tf_` (e.g., `tf_1234567890`)
    - 10DLC: `dlc_` (e.g., `dlc_1234567890`)
    - RCS: `rcs_` (e.g., `rcs_1234567890`)
    """

    type: CampaignEnum

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



import os
from typing import Dict, Any, Optional, Union, TypedDict
import json
from ...messages.client import MessagesClient, AsyncMessagesClient
from ...errors.unauthorized_error import UnauthorizedError
from ...errors.bad_request_error import BadRequestError
from ...types.error import Error
from ...types.user_event import UserEvent
from ...types.message_event import MessageEvent
from ...core.client_wrapper import SyncClientWrapper, AsyncClientWrapper
from ...core.pydantic_utilities import parse_obj_as


class PinnacleRequest(TypedDict):
    headers: Dict[str, Any]
    body: Union[str, bytes]


def _validate_webhook_secret(
    req: PinnacleRequest, secret: Optional[str] = None
) -> None:
    """Validate webhook signature for both sync and async clients."""
    header_secret = (
        req["headers"].get("PINNACLE-SIGNING-SECRET")
        or req["headers"].get("pinnacle-signing-secret")
        or req["headers"].get("Pinnacle-Signing-Secret")
    )

    env_secret = secret or os.environ.get("PINNACLE_SIGNING_SECRET")
    if header_secret is None:
        raise UnauthorizedError(
            body=Error(
                error="Failed to get the PINNACLE-SIGNING-SECRET header from request"
            )
        )
    if env_secret is None:
        raise UnauthorizedError(
            body=Error(
                error="Make sure to set the PINNACLE_SIGNING_SECRET environment variable or pass the secret as an argument to the process method"
            )
        )
    if header_secret != env_secret:
        raise UnauthorizedError(body=Error(error="Invalid webhook signature"))


class EnhancedMessages(MessagesClient):
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        super().__init__(client_wrapper=client_wrapper)

    def process(
        self, req: PinnacleRequest, secret: Optional[str] = None
    ) -> Union[MessageEvent, UserEvent]:
        """Process incoming webhook request from any supported framework.

        Args:
            request: Dictionary containing the headers and body (as a string) of the request
            secret: Optional webhook secret. Uses PINNACLE_SIGNING_SECRET env var if not provided.

        Returns:
            MessageEvent: The validated and parsed message event

        Raises:
            UnauthorizedError: If webhook signature is invalid or missing
            BadRequestError: If request cannot be parsed or is invalid
        """

        _validate_webhook_secret(req, secret)

        try:
            body = json.loads(req["body"])
            if body["type"] == "USER.TYPING":
                return parse_obj_as(UserEvent, body)
            else:
                return parse_obj_as(MessageEvent, body)
        except Exception as e:
            raise BadRequestError(body=f"Invalid message event format: {str(e)}")


class AsyncEnhancedMessages(AsyncMessagesClient):
    """Async version of MessageProcessor"""

    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        super().__init__(client_wrapper=client_wrapper)

    async def process(
        self, req: PinnacleRequest, secret: Optional[str] = None
    ) -> Union[MessageEvent, UserEvent]:
        """Process incoming webhook request from any supported async framework.

        Args:
            request: Dictionary containing the headers and body (as a string) of the request
            secret: Optional webhook secret. Uses PINNACLE_SIGNING_SECRET env var if not provided.

        Returns:
            MessageEvent: The validated and parsed message event

        Raises:
            UnauthorizedError: If webhook signature is invalid or missing
            BadRequestError: If request cannot be parsed or is invalid
        """

        _validate_webhook_secret(req, secret)

        try:
            body = json.loads(req["body"])
            if body["type"] == "USER.TYPING":
                return parse_obj_as(UserEvent, body)
            else:
                return parse_obj_as(MessageEvent, body)
        except Exception as e:
            raise BadRequestError(body=f"Invalid message event format: {str(e)}")



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.company_entity_type_enum import CompanyEntityTypeEnum
from ..types.company_sector_enum import CompanySectorEnum
from ..types.company_type_enum import CompanyTypeEnum
from ..types.extended_brand import ExtendedBrand
from ..types.extended_brand_with_vetting import ExtendedBrandWithVetting
from ..types.optional_brand_info import OptionalBrandInfo
from ..types.optional_contacts import OptionalContacts
from ..types.submission_results import SubmissionResults
from ..types.validation_results import ValidationResults
from ..types.vetting_results import VettingResults
from .raw_client import AsyncRawBrandsClient, RawBrandsClient
from .types.autofill_brand_options import AutofillBrandOptions
from .types.upsert_brand_schema_contact import UpsertBrandSchemaContact
from .types.upsert_brand_schema_entity_type import UpsertBrandSchemaEntityType
from .types.upsert_brand_schema_sector import UpsertBrandSchemaSector
from .types.upsert_brand_schema_type import UpsertBrandSchemaType

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class BrandsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawBrandsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawBrandsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawBrandsClient
        """
        return self._raw_client

    def autofill(
        self,
        *,
        additional_info: typing.Optional[str] = OMIT,
        name: typing.Optional[str] = OMIT,
        options: typing.Optional[AutofillBrandOptions] = OMIT,
        website: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OptionalBrandInfo:
        """
        Automatically populate brand information based on partial input data you provide.

        Parameters
        ----------
        additional_info : typing.Optional[str]
            Any extra details about the brand to help improve data accuracy.

        name : typing.Optional[str]
            Name of the brand.

        options : typing.Optional[AutofillBrandOptions]

        website : typing.Optional[str]
            Brand's website URL.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OptionalBrandInfo
            Returns enriched brand information retrieved from the autofill service.

        Examples
        --------
        from rcs import Pinnacle
        from rcs.brands import AutofillBrandOptions

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.brands.autofill(
            additional_info="A developer-friendly, compliant API for SMS, MMS, and RCS, built to scale real conversations.",
            name="Pinnacle",
            options=AutofillBrandOptions(
                force_reload=True,
            ),
            website="https://www.pinnacle.sh",
        )
        """
        _response = self._raw_client.autofill(
            additional_info=additional_info,
            name=name,
            options=options,
            website=website,
            request_options=request_options,
        )
        return _response.data

    def upsert(
        self,
        *,
        address: typing.Optional[str] = OMIT,
        contact: typing.Optional[UpsertBrandSchemaContact] = OMIT,
        dba: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        ein: typing.Optional[str] = OMIT,
        email: typing.Optional[str] = OMIT,
        id: typing.Optional[str] = OMIT,
        name: typing.Optional[str] = OMIT,
        sector: typing.Optional[UpsertBrandSchemaSector] = OMIT,
        type: typing.Optional[UpsertBrandSchemaType] = OMIT,
        entity_type: typing.Optional[UpsertBrandSchemaEntityType] = OMIT,
        website: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtendedBrand:
        """
        Create a new brand or update an existing one.

        <Note>
        **To create a new brand:** Omit `id` — one will be generated automatically.

        All fields are **required** except `description` and `dba`, and will be validated when [submitted](/api-reference/brands/submit).
        </Note>

        Parameters
        ----------
        address : typing.Optional[str]
            Primary brand address where the company is located.

        contact : typing.Optional[UpsertBrandSchemaContact]
            Contact information for the brand.

        dba : typing.Optional[str]
            "Doing Business As" name - the public name the brand operates under.

        description : typing.Optional[str]
            Brief description of what the brand does.

        ein : typing.Optional[str]
            Brand's Employer Identification Number (EIN) assigned by the IRS.

        email : typing.Optional[str]
            Main contact email address for the brand.

        id : typing.Optional[str]
            The unique identifier of the brand you want to update.
            <br><br> This identifier is a string that always begins with the prefix `b_`, for example: `b_1234567890`.

        name : typing.Optional[str]
            Legal name of the brand as registered.

        sector : typing.Optional[UpsertBrandSchemaSector]
            Industry the brand operates in.

        type : typing.Optional[UpsertBrandSchemaType]
            Legal structure of the brand.

        entity_type : typing.Optional[UpsertBrandSchemaEntityType]
            Legal entity type of the brand.

        website : typing.Optional[str]
            Brand website URL.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtendedBrand
            Successfully create/updated the brand.

        Examples
        --------
        from rcs import Pinnacle
        from rcs.brands import UpsertBrandSchemaContact

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.brands.upsert(
            address="500 Folsom St, San Francisco, CA 94105",
            contact=UpsertBrandSchemaContact(
                email="michael.chen@trypinnacle.app",
                name="Michael Chen",
                phone="+14155551234",
                title="Customer Support Representative",
            ),
            dba="Pinnacle RCS",
            description="A developer-friendly, compliant API for SMS, MMS, and RCS, built to scale real conversations.",
            ein="88-1234567",
            email="founders@trypinnacle.app",
            id="b_1234567890",
            name="Pinnacle",
            sector="TECHNOLOGY",
            type="PRIVATE_PROFIT",
            entity_type="LLC",
            website="https://www.pinnacle.sh",
        )
        """
        _response = self._raw_client.upsert(
            address=address,
            contact=contact,
            dba=dba,
            description=description,
            ein=ein,
            email=email,
            id=id,
            name=name,
            sector=sector,
            type=type,
            entity_type=entity_type,
            website=website,
            request_options=request_options,
        )
        return _response.data

    def get(
        self,
        id: str,
        *,
        hide_ein: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtendedBrandWithVetting:
        """
        Retrieve detailed information for a specific brand in your account by ID.

        Parameters
        ----------
        id : str
            The unique identifier of the brand you want to retrieve from your account.
            <br><br> This identifier is a string that always begins with the prefix `b_`, for example: `b_1234567890`.

        hide_ein : typing.Optional[bool]
            Optional flag to mask the Employer Identification Number in the response for security purposes.<br>

            When you set this to true, the EIN value will be replaced with a masked placeholder instead of the actual number.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtendedBrandWithVetting
            Returns the brand.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.brands.get(
            id="b_1234567890",
        )
        """
        _response = self._raw_client.get(id, hide_ein=hide_ein, request_options=request_options)
        return _response.data

    def submit(self, brand_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> SubmissionResults:
        """
        Submit your brand for review and approval by the compliance team.

        Parameters
        ----------
        brand_id : str
            The unique identifier of the brand you want to submit for review. <br><br>
            This identifier is a string that always begins with the prefix `b_`, for example: `b_1234567890` and must correspond to an existing brand in your account that is ready for submission.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SubmissionResults
            Successfully submitted brand information.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.brands.submit(
            brand_id="b_1234567890",
        )
        """
        _response = self._raw_client.submit(brand_id, request_options=request_options)
        return _response.data

    def validate(
        self,
        *,
        address: typing.Optional[str] = OMIT,
        contact: typing.Optional[OptionalContacts] = OMIT,
        dba: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        ein: typing.Optional[str] = OMIT,
        email: typing.Optional[str] = OMIT,
        name: typing.Optional[str] = OMIT,
        sector: typing.Optional[CompanySectorEnum] = OMIT,
        type: typing.Optional[CompanyTypeEnum] = OMIT,
        entity_type: typing.Optional[CompanyEntityTypeEnum] = OMIT,
        website: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ValidationResults:
        """
        Validate your brand information for compliance and correctness before submission or storage.

        Parameters
        ----------
        address : typing.Optional[str]
            Primary brand address where this brand is located.

        contact : typing.Optional[OptionalContacts]

        dba : typing.Optional[str]
            "Doing Business As" name - the public name this brand operates under.

        description : typing.Optional[str]
            Brief description of what this brand does.

        ein : typing.Optional[str]
            Employer Identification Number (EIN) assigned by the IRS.

        email : typing.Optional[str]
            Main contact email address for this brand.

        name : typing.Optional[str]
            Legal name of the brand as registered.

        sector : typing.Optional[CompanySectorEnum]

        type : typing.Optional[CompanyTypeEnum]

        entity_type : typing.Optional[CompanyEntityTypeEnum]
            Legal entity type of the brand.

        website : typing.Optional[str]
            Brand website URL.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ValidationResults
            Returns the brand validation result.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.brands.validate()
        """
        _response = self._raw_client.validate(
            address=address,
            contact=contact,
            dba=dba,
            description=description,
            ein=ein,
            email=email,
            name=name,
            sector=sector,
            type=type,
            entity_type=entity_type,
            website=website,
            request_options=request_options,
        )
        return _response.data

    def vet(self, brand_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> VettingResults:
        """
        Submit a brand for external vetting verification to enhance your brand's trust score and improved message delivery rates.

        Parameters
        ----------
        brand_id : str
            The unique identifier of the brand to vet. <br>

            This identifier is a string that always begins with the prefix `b_`, for example: `b_1234567890` and must correspond to an existing brand in your account that is ready for vetting.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        VettingResults
            Successfully initiated brand vetting process.

        Examples
        --------
        from rcs import Pinnacle

        client = Pinnacle(
            api_key="YOUR_API_KEY",
        )
        client.brands.vet(
            brand_id="b_1234567890",
        )
        """
        _response = self._raw_client.vet(brand_id, request_options=request_options)
        return _response.data


class AsyncBrandsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawBrandsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawBrandsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawBrandsClient
        """
        return self._raw_client

    async def autofill(
        self,
        *,
        additional_info: typing.Optional[str] = OMIT,
        name: typing.Optional[str] = OMIT,
        options: typing.Optional[AutofillBrandOptions] = OMIT,
        website: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> OptionalBrandInfo:
        """
        Automatically populate brand information based on partial input data you provide.

        Parameters
        ----------
        additional_info : typing.Optional[str]
            Any extra details about the brand to help improve data accuracy.

        name : typing.Optional[str]
            Name of the brand.

        options : typing.Optional[AutofillBrandOptions]

        website : typing.Optional[str]
            Brand's website URL.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        OptionalBrandInfo
            Returns enriched brand information retrieved from the autofill service.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle
        from rcs.brands import AutofillBrandOptions

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.brands.autofill(
                additional_info="A developer-friendly, compliant API for SMS, MMS, and RCS, built to scale real conversations.",
                name="Pinnacle",
                options=AutofillBrandOptions(
                    force_reload=True,
                ),
                website="https://www.pinnacle.sh",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.autofill(
            additional_info=additional_info,
            name=name,
            options=options,
            website=website,
            request_options=request_options,
        )
        return _response.data

    async def upsert(
        self,
        *,
        address: typing.Optional[str] = OMIT,
        contact: typing.Optional[UpsertBrandSchemaContact] = OMIT,
        dba: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        ein: typing.Optional[str] = OMIT,
        email: typing.Optional[str] = OMIT,
        id: typing.Optional[str] = OMIT,
        name: typing.Optional[str] = OMIT,
        sector: typing.Optional[UpsertBrandSchemaSector] = OMIT,
        type: typing.Optional[UpsertBrandSchemaType] = OMIT,
        entity_type: typing.Optional[UpsertBrandSchemaEntityType] = OMIT,
        website: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtendedBrand:
        """
        Create a new brand or update an existing one.

        <Note>
        **To create a new brand:** Omit `id` — one will be generated automatically.

        All fields are **required** except `description` and `dba`, and will be validated when [submitted](/api-reference/brands/submit).
        </Note>

        Parameters
        ----------
        address : typing.Optional[str]
            Primary brand address where the company is located.

        contact : typing.Optional[UpsertBrandSchemaContact]
            Contact information for the brand.

        dba : typing.Optional[str]
            "Doing Business As" name - the public name the brand operates under.

        description : typing.Optional[str]
            Brief description of what the brand does.

        ein : typing.Optional[str]
            Brand's Employer Identification Number (EIN) assigned by the IRS.

        email : typing.Optional[str]
            Main contact email address for the brand.

        id : typing.Optional[str]
            The unique identifier of the brand you want to update.
            <br><br> This identifier is a string that always begins with the prefix `b_`, for example: `b_1234567890`.

        name : typing.Optional[str]
            Legal name of the brand as registered.

        sector : typing.Optional[UpsertBrandSchemaSector]
            Industry the brand operates in.

        type : typing.Optional[UpsertBrandSchemaType]
            Legal structure of the brand.

        entity_type : typing.Optional[UpsertBrandSchemaEntityType]
            Legal entity type of the brand.

        website : typing.Optional[str]
            Brand website URL.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtendedBrand
            Successfully create/updated the brand.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle
        from rcs.brands import UpsertBrandSchemaContact

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.brands.upsert(
                address="500 Folsom St, San Francisco, CA 94105",
                contact=UpsertBrandSchemaContact(
                    email="michael.chen@trypinnacle.app",
                    name="Michael Chen",
                    phone="+14155551234",
                    title="Customer Support Representative",
                ),
                dba="Pinnacle RCS",
                description="A developer-friendly, compliant API for SMS, MMS, and RCS, built to scale real conversations.",
                ein="88-1234567",
                email="founders@trypinnacle.app",
                id="b_1234567890",
                name="Pinnacle",
                sector="TECHNOLOGY",
                type="PRIVATE_PROFIT",
                entity_type="LLC",
                website="https://www.pinnacle.sh",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.upsert(
            address=address,
            contact=contact,
            dba=dba,
            description=description,
            ein=ein,
            email=email,
            id=id,
            name=name,
            sector=sector,
            type=type,
            entity_type=entity_type,
            website=website,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self,
        id: str,
        *,
        hide_ein: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtendedBrandWithVetting:
        """
        Retrieve detailed information for a specific brand in your account by ID.

        Parameters
        ----------
        id : str
            The unique identifier of the brand you want to retrieve from your account.
            <br><br> This identifier is a string that always begins with the prefix `b_`, for example: `b_1234567890`.

        hide_ein : typing.Optional[bool]
            Optional flag to mask the Employer Identification Number in the response for security purposes.<br>

            When you set this to true, the EIN value will be replaced with a masked placeholder instead of the actual number.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtendedBrandWithVetting
            Returns the brand.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.brands.get(
                id="b_1234567890",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, hide_ein=hide_ein, request_options=request_options)
        return _response.data

    async def submit(
        self, brand_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SubmissionResults:
        """
        Submit your brand for review and approval by the compliance team.

        Parameters
        ----------
        brand_id : str
            The unique identifier of the brand you want to submit for review. <br><br>
            This identifier is a string that always begins with the prefix `b_`, for example: `b_1234567890` and must correspond to an existing brand in your account that is ready for submission.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SubmissionResults
            Successfully submitted brand information.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.brands.submit(
                brand_id="b_1234567890",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.submit(brand_id, request_options=request_options)
        return _response.data

    async def validate(
        self,
        *,
        address: typing.Optional[str] = OMIT,
        contact: typing.Optional[OptionalContacts] = OMIT,
        dba: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        ein: typing.Optional[str] = OMIT,
        email: typing.Optional[str] = OMIT,
        name: typing.Optional[str] = OMIT,
        sector: typing.Optional[CompanySectorEnum] = OMIT,
        type: typing.Optional[CompanyTypeEnum] = OMIT,
        entity_type: typing.Optional[CompanyEntityTypeEnum] = OMIT,
        website: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ValidationResults:
        """
        Validate your brand information for compliance and correctness before submission or storage.

        Parameters
        ----------
        address : typing.Optional[str]
            Primary brand address where this brand is located.

        contact : typing.Optional[OptionalContacts]

        dba : typing.Optional[str]
            "Doing Business As" name - the public name this brand operates under.

        description : typing.Optional[str]
            Brief description of what this brand does.

        ein : typing.Optional[str]
            Employer Identification Number (EIN) assigned by the IRS.

        email : typing.Optional[str]
            Main contact email address for this brand.

        name : typing.Optional[str]
            Legal name of the brand as registered.

        sector : typing.Optional[CompanySectorEnum]

        type : typing.Optional[CompanyTypeEnum]

        entity_type : typing.Optional[CompanyEntityTypeEnum]
            Legal entity type of the brand.

        website : typing.Optional[str]
            Brand website URL.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ValidationResults
            Returns the brand validation result.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.brands.validate()


        asyncio.run(main())
        """
        _response = await self._raw_client.validate(
            address=address,
            contact=contact,
            dba=dba,
            description=description,
            ein=ein,
            email=email,
            name=name,
            sector=sector,
            type=type,
            entity_type=entity_type,
            website=website,
            request_options=request_options,
        )
        return _response.data

    async def vet(self, brand_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> VettingResults:
        """
        Submit a brand for external vetting verification to enhance your brand's trust score and improved message delivery rates.

        Parameters
        ----------
        brand_id : str
            The unique identifier of the brand to vet. <br>

            This identifier is a string that always begins with the prefix `b_`, for example: `b_1234567890` and must correspond to an existing brand in your account that is ready for vetting.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        VettingResults
            Successfully initiated brand vetting process.

        Examples
        --------
        import asyncio

        from rcs import AsyncPinnacle

        client = AsyncPinnacle(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.brands.vet(
                brand_id="b_1234567890",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.vet(brand_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class ConversationContact(UniversalBaseModel):
    """
    Contact information for the recipient in a conversation.
    """

    id: str = pydantic.Field()
    """
    Unique ID of the contact. This identifier is a string that always begins with the prefix `co_`, for example: `co_1234567890`.
    """

    phone_number: typing_extensions.Annotated[str, FieldMetadata(alias="phoneNumber")] = pydantic.Field()
    """
    The contact's phone number in E.164 format.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class SearchPhoneNumberByLocation(UniversalBaseModel):
    """
    Filter your search by geographic location to find numbers in specific regions. <br>

    Toll-free numbers ignore city and state filters.
    """

    city: typing.Optional[str] = pydantic.Field(default=None)
    """
    Search for numbers in your target city.
    """

    country_code: typing_extensions.Annotated[
        typing.Optional[typing.Literal["US"]], FieldMetadata(alias="countryCode")
    ] = pydantic.Field(default=None)
    """
    Currently, only US numbers are supported.
    """

    national_destination_code: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="nationalDestinationCode")
    ] = pydantic.Field(default=None)
    """
    Narrow your search to a specific area or exchange code. <br>
    
    For US numbers, this is usually the 3-digit area code.
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    Search for numbers in your target state or province using a two-letter code.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .advanced_phone_information import AdvancedPhoneInformation
    from .advanced_phone_information_carrier import AdvancedPhoneInformationCarrier
    from .advanced_phone_information_contact import AdvancedPhoneInformationContact
    from .advanced_phone_information_location import AdvancedPhoneInformationLocation
    from .advanced_phone_information_location_coordinates import AdvancedPhoneInformationLocationCoordinates
    from .advanced_phone_information_location_country import AdvancedPhoneInformationLocationCountry
    from .advanced_phone_information_type import AdvancedPhoneInformationType
    from .advanced_phone_information_type_recommendation import AdvancedPhoneInformationTypeRecommendation
    from .agent import Agent
    from .attach_webhook_by_id_params import AttachWebhookByIdParams
    from .attach_webhook_params import AttachWebhookParams
    from .attach_webhook_response_webhook import AttachWebhookResponseWebhook
    from .attached_phone_number_result import AttachedPhoneNumberResult
    from .audience_count_only import AudienceCountOnly
    from .audience_with_pagination import AudienceWithPagination
    from .autofill_campaign_params import AutofillCampaignParams
    from .autofill_dlc_campaign_response import AutofillDlcCampaignResponse
    from .autofill_dlc_response_keywords import AutofillDlcResponseKeywords
    from .autofill_dlc_response_keywords_help import AutofillDlcResponseKeywordsHelp
    from .autofill_dlc_response_keywords_opt_in import AutofillDlcResponseKeywordsOptIn
    from .autofill_dlc_response_keywords_opt_out import AutofillDlcResponseKeywordsOptOut
    from .autofill_dlc_response_links import AutofillDlcResponseLinks
    from .autofill_dlc_response_options import AutofillDlcResponseOptions
    from .autofill_dlc_response_use_case import AutofillDlcResponseUseCase
    from .bad_request_error_body import BadRequestErrorBody
    from .base_rich_message import BaseRichMessage
    from .basic_phone_information import BasicPhoneInformation
    from .basic_phone_information_contact import BasicPhoneInformationContact
    from .basic_phone_information_location import BasicPhoneInformationLocation
    from .basic_phone_information_location_country import BasicPhoneInformationLocationCountry
    from .blast_details import BlastDetails
    from .brand_status import BrandStatus
    from .brand_status_enum import BrandStatusEnum
    from .button_clicked import ButtonClicked
    from .button_clicked_data import ButtonClickedData
    from .button_clicked_data_button import ButtonClickedDataButton
    from .button_clicked_data_button_raw import ButtonClickedDataButtonRaw
    from .button_clicked_data_button_type import ButtonClickedDataButtonType
    from .buy_response_capabilities import BuyResponseCapabilities
    from .campaign_enum import CampaignEnum
    from .campaign_query import CampaignQuery
    from .campaign_submission_result import CampaignSubmissionResult
    from .campaign_validation_response_errors_item import CampaignValidationResponseErrorsItem
    from .campaign_validation_result import CampaignValidationResult
    from .company_entity_type_enum import CompanyEntityTypeEnum
    from .company_sector_enum import CompanySectorEnum
    from .company_type_enum import CompanyTypeEnum
    from .configured_webhook import ConfiguredWebhook
    from .contact import Contact
    from .contact_id import ContactId
    from .conversation import Conversation
    from .conversation_by_id_params import ConversationByIdParams
    from .conversation_by_participants_params import ConversationByParticipantsParams
    from .conversation_contact import ConversationContact
    from .conversation_list import ConversationList
    from .conversation_sender import ConversationSender
    from .create_and_attach_webhook_by_url_params import CreateAndAttachWebhookByUrlParams
    from .create_url_options import CreateUrlOptions
    from .delete_audience_response import DeleteAudienceResponse
    from .detached_phone_number_result import DetachedPhoneNumberResult
    from .detached_webhook_info import DetachedWebhookInfo
    from .detailed_phone_number_enum import DetailedPhoneNumberEnum
    from .dlc_assignment_status_enum import DlcAssignmentStatusEnum
    from .dlc_campaign_status import DlcCampaignStatus
    from .dlc_campaign_use_case_enum import DlcCampaignUseCaseEnum
    from .dlc_campaign_with_extended_brand_and_status import DlcCampaignWithExtendedBrandAndStatus
    from .dlc_with_extended_brand_and_status_keywords import DlcWithExtendedBrandAndStatusKeywords
    from .dlc_with_extended_brand_and_status_keywords_help import DlcWithExtendedBrandAndStatusKeywordsHelp
    from .dlc_with_extended_brand_and_status_keywords_opt_in import DlcWithExtendedBrandAndStatusKeywordsOptIn
    from .dlc_with_extended_brand_and_status_keywords_opt_out import DlcWithExtendedBrandAndStatusKeywordsOptOut
    from .dlc_with_extended_brand_and_status_links import DlcWithExtendedBrandAndStatusLinks
    from .dlc_with_extended_brand_and_status_mno_brand_tier import DlcWithExtendedBrandAndStatusMnoBrandTier
    from .dlc_with_extended_brand_and_status_mno_tcr_tier import DlcWithExtendedBrandAndStatusMnoTcrTier
    from .dlc_with_extended_brand_and_status_options import DlcWithExtendedBrandAndStatusOptions
    from .dlc_with_extended_brand_and_status_use_case import DlcWithExtendedBrandAndStatusUseCase
    from .enhanced_contact import EnhancedContact
    from .enhanced_contact_item import EnhancedContactItem
    from .error import Error
    from .extended_brand import ExtendedBrand
    from .extended_brand_with_vetting import ExtendedBrandWithVetting
    from .extended_rcs_campaign import ExtendedRcsCampaign
    from .get_conversation_params import GetConversationParams
    from .get_dlc_campaign_status_response_updates import GetDlcCampaignStatusResponseUpdates
    from .get_toll_free_campaign_status_response_updates import GetTollFreeCampaignStatusResponseUpdates
    from .link_click_event import LinkClickEvent
    from .location_share_action import LocationShareAction
    from .location_share_action_data import LocationShareActionData
    from .message import Message
    from .message_content import MessageContent
    from .message_event import MessageEvent
    from .message_event_content import MessageEventContent
    from .message_event_conversation import MessageEventConversation
    from .message_event_direction import MessageEventDirection
    from .message_event_mms_content import MessageEventMmsContent
    from .message_event_rcs_button_data import MessageEventRcsButtonData
    from .message_event_rcs_cards_content import MessageEventRcsCardsContent
    from .message_event_rcs_cards_content_cards_item import MessageEventRcsCardsContentCardsItem
    from .message_event_rcs_location_data import MessageEventRcsLocationData
    from .message_event_rcs_media_content import MessageEventRcsMediaContent
    from .message_event_rcs_text_content import MessageEventRcsTextContent
    from .message_event_sms_content import MessageEventSmsContent
    from .message_list import MessageList
    from .message_method_enum import MessageMethodEnum
    from .message_protocol_enum import MessageProtocolEnum
    from .message_schedule import MessageSchedule
    from .message_status_enum import MessageStatusEnum
    from .message_volume_enum import MessageVolumeEnum
    from .message_with_reaction import MessageWithReaction
    from .message_with_reaction_direction import MessageWithReactionDirection
    from .messaging_profile_enum import MessagingProfileEnum
    from .mms_content import MmsContent
    from .mms_validation_response_segments import MmsValidationResponseSegments
    from .mms_validation_response_segments_value_item import MmsValidationResponseSegmentsValueItem
    from .mms_validation_result import MmsValidationResult
    from .not_found_error_body import NotFoundErrorBody
    from .number_format import NumberFormat
    from .opt_in_method_enum import OptInMethodEnum
    from .optional_brand_info import OptionalBrandInfo
    from .optional_contact import OptionalContact
    from .optional_contacts import OptionalContacts
    from .pagination import Pagination
    from .phone import Phone
    from .phone_capabilities import PhoneCapabilities
    from .phone_enum import PhoneEnum
    from .phone_feature_enum import PhoneFeatureEnum
    from .phone_number_campaign_attach_failed_item import PhoneNumberCampaignAttachFailedItem
    from .phone_number_campaign_attach_phone_numbers_item import PhoneNumberCampaignAttachPhoneNumbersItem
    from .phone_number_campaign_attach_phone_numbers_item_campaign import (
        PhoneNumberCampaignAttachPhoneNumbersItemCampaign,
    )
    from .phone_number_campaign_detach_failed_item import PhoneNumberCampaignDetachFailedItem
    from .phone_number_campaign_detach_phone_numbers_item import PhoneNumberCampaignDetachPhoneNumbersItem
    from .phone_number_campaign_detach_phone_numbers_item_campaign import (
        PhoneNumberCampaignDetachPhoneNumbersItemCampaign,
    )
    from .phone_number_cost import PhoneNumberCost
    from .phone_number_details import PhoneNumberDetails
    from .phone_number_enum import PhoneNumberEnum
    from .phone_number_region import PhoneNumberRegion
    from .phone_number_status import PhoneNumberStatus
    from .phone_number_status_enum import PhoneNumberStatusEnum
    from .pinnacle_file_upload_metadata import PinnacleFileUploadMetadata
    from .pinnacle_url_config import PinnacleUrlConfig
    from .profile_status_enum import ProfileStatusEnum
    from .purchased_number import PurchasedNumber
    from .rcs_button_call import RcsButtonCall
    from .rcs_button_open_url import RcsButtonOpenUrl
    from .rcs_button_open_url_webview_mode import RcsButtonOpenUrlWebviewMode
    from .rcs_button_request_user_location import RcsButtonRequestUserLocation
    from .rcs_button_schedule_event import RcsButtonScheduleEvent
    from .rcs_button_send_location import RcsButtonSendLocation
    from .rcs_button_send_location_lat_long import RcsButtonSendLocationLatLong
    from .rcs_button_trigger import RcsButtonTrigger
    from .rcs_campaign import RcsCampaign
    from .rcs_campaign_schema_agent import RcsCampaignSchemaAgent
    from .rcs_campaign_schema_agent_emails_item import RcsCampaignSchemaAgentEmailsItem
    from .rcs_campaign_schema_agent_phones_item import RcsCampaignSchemaAgentPhonesItem
    from .rcs_campaign_schema_agent_websites_item import RcsCampaignSchemaAgentWebsitesItem
    from .rcs_campaign_schema_extra_agent import RcsCampaignSchemaExtraAgent
    from .rcs_campaign_schema_extra_agent_emails_item import RcsCampaignSchemaExtraAgentEmailsItem
    from .rcs_campaign_schema_extra_agent_phones_item import RcsCampaignSchemaExtraAgentPhonesItem
    from .rcs_campaign_schema_extra_agent_websites_item import RcsCampaignSchemaExtraAgentWebsitesItem
    from .rcs_campaign_schema_extra_keywords import RcsCampaignSchemaExtraKeywords
    from .rcs_campaign_schema_extra_keywords_help import RcsCampaignSchemaExtraKeywordsHelp
    from .rcs_campaign_schema_extra_keywords_opt_in import RcsCampaignSchemaExtraKeywordsOptIn
    from .rcs_campaign_schema_extra_keywords_opt_out import RcsCampaignSchemaExtraKeywordsOptOut
    from .rcs_campaign_schema_extra_links import RcsCampaignSchemaExtraLinks
    from .rcs_campaign_schema_extra_traffic import RcsCampaignSchemaExtraTraffic
    from .rcs_campaign_schema_extra_use_case import RcsCampaignSchemaExtraUseCase
    from .rcs_campaign_schema_keywords import RcsCampaignSchemaKeywords
    from .rcs_campaign_schema_keywords_help import RcsCampaignSchemaKeywordsHelp
    from .rcs_campaign_schema_keywords_opt_in import RcsCampaignSchemaKeywordsOptIn
    from .rcs_campaign_schema_keywords_opt_out import RcsCampaignSchemaKeywordsOptOut
    from .rcs_campaign_schema_links import RcsCampaignSchemaLinks
    from .rcs_campaign_schema_traffic import RcsCampaignSchemaTraffic
    from .rcs_campaign_schema_use_case import RcsCampaignSchemaUseCase
    from .rcs_campaign_status import RcsCampaignStatus
    from .rcs_campaign_use_case_enum import RcsCampaignUseCaseEnum
    from .rcs_capabilities_result import RcsCapabilitiesResult
    from .rcs_capability import RcsCapability
    from .rcs_capability_actions import RcsCapabilityActions
    from .rcs_capability_cards import RcsCapabilityCards
    from .rcs_cards_content import RcsCardsContent
    from .rcs_cards_content_cards_item import RcsCardsContentCardsItem
    from .rcs_content import RcsContent
    from .rcs_link_result import RcsLinkResult
    from .rcs_media_content import RcsMediaContent
    from .rcs_media_details_content import RcsMediaDetailsContent
    from .rcs_messaging_type_enum import RcsMessagingTypeEnum
    from .rcs_validate_content import RcsValidateContent
    from .rcs_validate_content_media import RcsValidateContentMedia
    from .rcs_validation_result import RcsValidationResult
    from .rcs_whitelist_response import RcsWhitelistResponse
    from .reaction_result import ReactionResult
    from .refreshed_file import RefreshedFile
    from .rich_button import (
        RichButton,
        RichButton_Call,
        RichButton_OpenUrl,
        RichButton_RequestUserLocation,
        RichButton_ScheduleEvent,
        RichButton_SendLocation,
        RichButton_Trigger,
    )
    from .rich_card import RichCard
    from .rich_cards import RichCards
    from .rich_cards_message import RichCardsMessage
    from .rich_media_message import RichMediaMessage
    from .rich_message import RichMessage
    from .rich_standalone_card_options import RichStandaloneCardOptions
    from .rich_text import RichText
    from .rich_text_message import RichTextMessage
    from .schedule_cancel_result import ScheduleCancelResult
    from .scheduled_blast_details import ScheduledBlastDetails
    from .scheduled_blast_response_config import ScheduledBlastResponseConfig
    from .scheduled_message import ScheduledMessage
    from .scheduled_send_response_config import ScheduledSendResponseConfig
    from .send_rcs_card_options_standalone_card_image_alignment import SendRcsCardOptionsStandaloneCardImageAlignment
    from .send_rcs_card_options_standalone_card_orientation import SendRcsCardOptionsStandaloneCardOrientation
    from .send_rich_cards_options import SendRichCardsOptions
    from .send_rich_message_options import SendRichMessageOptions
    from .send_sms_response_segments import SendSmsResponseSegments
    from .send_sms_response_segments_encoding import SendSmsResponseSegmentsEncoding
    from .send_typing_indicator_response import SendTypingIndicatorResponse
    from .sender import Sender
    from .sent_mms_details import SentMmsDetails
    from .sent_rich_message import SentRichMessage
    from .sent_sms_details import SentSmsDetails
    from .shortened_url import ShortenedUrl
    from .shortened_url_with_click_data import ShortenedUrlWithClickData
    from .sms_content import SmsContent
    from .sms_validation_response_segments import SmsValidationResponseSegments
    from .sms_validation_response_segments_gsm_7 import SmsValidationResponseSegmentsGsm7
    from .sms_validation_response_segments_utf_16 import SmsValidationResponseSegmentsUtf16
    from .sms_validation_response_total import SmsValidationResponseTotal
    from .sms_validation_result import SmsValidationResult
    from .sub_use_case_enum import SubUseCaseEnum
    from .submission_results import SubmissionResults
    from .successful_conversation_update import SuccessfulConversationUpdate
    from .toll_free_campaign import TollFreeCampaign
    from .toll_free_campaign_schema_keywords import TollFreeCampaignSchemaKeywords
    from .toll_free_campaign_schema_keywords_help import TollFreeCampaignSchemaKeywordsHelp
    from .toll_free_campaign_schema_keywords_opt_in import TollFreeCampaignSchemaKeywordsOptIn
    from .toll_free_campaign_schema_links import TollFreeCampaignSchemaLinks
    from .toll_free_campaign_schema_opt_in import TollFreeCampaignSchemaOptIn
    from .toll_free_campaign_schema_options import TollFreeCampaignSchemaOptions
    from .toll_free_campaign_schema_use_case import TollFreeCampaignSchemaUseCase
    from .toll_free_campaign_status import TollFreeCampaignStatus
    from .toll_free_campaign_use_case_enum import TollFreeCampaignUseCaseEnum
    from .toll_free_campaign_with_extended_brand_and_status import TollFreeCampaignWithExtendedBrandAndStatus
    from .toll_free_status_enum import TollFreeStatusEnum
    from .toll_free_with_extended_brand_and_status_keywords import TollFreeWithExtendedBrandAndStatusKeywords
    from .toll_free_with_extended_brand_and_status_keywords_help import TollFreeWithExtendedBrandAndStatusKeywordsHelp
    from .toll_free_with_extended_brand_and_status_keywords_opt_in import (
        TollFreeWithExtendedBrandAndStatusKeywordsOptIn,
    )
    from .toll_free_with_extended_brand_and_status_links import TollFreeWithExtendedBrandAndStatusLinks
    from .toll_free_with_extended_brand_and_status_opt_in import TollFreeWithExtendedBrandAndStatusOptIn
    from .toll_free_with_extended_brand_and_status_options import TollFreeWithExtendedBrandAndStatusOptions
    from .toll_free_with_extended_brand_and_status_use_case import TollFreeWithExtendedBrandAndStatusUseCase
    from .tracking import Tracking
    from .updated_contact_id import UpdatedContactId
    from .upload_results import UploadResults
    from .user_event import UserEvent
    from .user_event_conversation import UserEventConversation
    from .v_card_address_schema_type_item import VCardAddressSchemaTypeItem
    from .v_card_data import VCardData
    from .v_card_data_file import VCardDataFile
    from .v_card_data_file_metadata import VCardDataFileMetadata
    from .v_card_email_schema_type_item import VCardEmailSchemaTypeItem
    from .v_card_geo import VCardGeo
    from .v_card_name import VCardName
    from .v_card_organization import VCardOrganization
    from .v_card_phone_schema_type_item import VCardPhoneSchemaTypeItem
    from .validate_campaign_params import ValidateCampaignParams
    from .validation_error_details import ValidationErrorDetails
    from .validation_results import ValidationResults
    from .vcard import Vcard
    from .vcard_address import VcardAddress
    from .vcard_content import VcardContent
    from .vcard_email import VcardEmail
    from .vcard_phone import VcardPhone
    from .vcard_resource import VcardResource
    from .vetting_feedback import VettingFeedback
    from .vetting_history import VettingHistory
    from .vetting_history_vetting_status import VettingHistoryVettingStatus
    from .vetting_results import VettingResults
    from .webhook_event_enum import WebhookEventEnum
    from .webhook_result import WebhookResult
    from .webhooks import Webhooks
    from .zod_error import ZodError
_dynamic_imports: typing.Dict[str, str] = {
    "AdvancedPhoneInformation": ".advanced_phone_information",
    "AdvancedPhoneInformationCarrier": ".advanced_phone_information_carrier",
    "AdvancedPhoneInformationContact": ".advanced_phone_information_contact",
    "AdvancedPhoneInformationLocation": ".advanced_phone_information_location",
    "AdvancedPhoneInformationLocationCoordinates": ".advanced_phone_information_location_coordinates",
    "AdvancedPhoneInformationLocationCountry": ".advanced_phone_information_location_country",
    "AdvancedPhoneInformationType": ".advanced_phone_information_type",
    "AdvancedPhoneInformationTypeRecommendation": ".advanced_phone_information_type_recommendation",
    "Agent": ".agent",
    "AttachWebhookByIdParams": ".attach_webhook_by_id_params",
    "AttachWebhookParams": ".attach_webhook_params",
    "AttachWebhookResponseWebhook": ".attach_webhook_response_webhook",
    "AttachedPhoneNumberResult": ".attached_phone_number_result",
    "AudienceCountOnly": ".audience_count_only",
    "AudienceWithPagination": ".audience_with_pagination",
    "AutofillCampaignParams": ".autofill_campaign_params",
    "AutofillDlcCampaignResponse": ".autofill_dlc_campaign_response",
    "AutofillDlcResponseKeywords": ".autofill_dlc_response_keywords",
    "AutofillDlcResponseKeywordsHelp": ".autofill_dlc_response_keywords_help",
    "AutofillDlcResponseKeywordsOptIn": ".autofill_dlc_response_keywords_opt_in",
    "AutofillDlcResponseKeywordsOptOut": ".autofill_dlc_response_keywords_opt_out",
    "AutofillDlcResponseLinks": ".autofill_dlc_response_links",
    "AutofillDlcResponseOptions": ".autofill_dlc_response_options",
    "AutofillDlcResponseUseCase": ".autofill_dlc_response_use_case",
    "BadRequestErrorBody": ".bad_request_error_body",
    "BaseRichMessage": ".base_rich_message",
    "BasicPhoneInformation": ".basic_phone_information",
    "BasicPhoneInformationContact": ".basic_phone_information_contact",
    "BasicPhoneInformationLocation": ".basic_phone_information_location",
    "BasicPhoneInformationLocationCountry": ".basic_phone_information_location_country",
    "BlastDetails": ".blast_details",
    "BrandStatus": ".brand_status",
    "BrandStatusEnum": ".brand_status_enum",
    "ButtonClicked": ".button_clicked",
    "ButtonClickedData": ".button_clicked_data",
    "ButtonClickedDataButton": ".button_clicked_data_button",
    "ButtonClickedDataButtonRaw": ".button_clicked_data_button_raw",
    "ButtonClickedDataButtonType": ".button_clicked_data_button_type",
    "BuyResponseCapabilities": ".buy_response_capabilities",
    "CampaignEnum": ".campaign_enum",
    "CampaignQuery": ".campaign_query",
    "CampaignSubmissionResult": ".campaign_submission_result",
    "CampaignValidationResponseErrorsItem": ".campaign_validation_response_errors_item",
    "CampaignValidationResult": ".campaign_validation_result",
    "CompanyEntityTypeEnum": ".company_entity_type_enum",
    "CompanySectorEnum": ".company_sector_enum",
    "CompanyTypeEnum": ".company_type_enum",
    "ConfiguredWebhook": ".configured_webhook",
    "Contact": ".contact",
    "ContactId": ".contact_id",
    "Conversation": ".conversation",
    "ConversationByIdParams": ".conversation_by_id_params",
    "ConversationByParticipantsParams": ".conversation_by_participants_params",
    "ConversationContact": ".conversation_contact",
    "ConversationList": ".conversation_list",
    "ConversationSender": ".conversation_sender",
    "CreateAndAttachWebhookByUrlParams": ".create_and_attach_webhook_by_url_params",
    "CreateUrlOptions": ".create_url_options",
    "DeleteAudienceResponse": ".delete_audience_response",
    "DetachedPhoneNumberResult": ".detached_phone_number_result",
    "DetachedWebhookInfo": ".detached_webhook_info",
    "DetailedPhoneNumberEnum": ".detailed_phone_number_enum",
    "DlcAssignmentStatusEnum": ".dlc_assignment_status_enum",
    "DlcCampaignStatus": ".dlc_campaign_status",
    "DlcCampaignUseCaseEnum": ".dlc_campaign_use_case_enum",
    "DlcCampaignWithExtendedBrandAndStatus": ".dlc_campaign_with_extended_brand_and_status",
    "DlcWithExtendedBrandAndStatusKeywords": ".dlc_with_extended_brand_and_status_keywords",
    "DlcWithExtendedBrandAndStatusKeywordsHelp": ".dlc_with_extended_brand_and_status_keywords_help",
    "DlcWithExtendedBrandAndStatusKeywordsOptIn": ".dlc_with_extended_brand_and_status_keywords_opt_in",
    "DlcWithExtendedBrandAndStatusKeywordsOptOut": ".dlc_with_extended_brand_and_status_keywords_opt_out",
    "DlcWithExtendedBrandAndStatusLinks": ".dlc_with_extended_brand_and_status_links",
    "DlcWithExtendedBrandAndStatusMnoBrandTier": ".dlc_with_extended_brand_and_status_mno_brand_tier",
    "DlcWithExtendedBrandAndStatusMnoTcrTier": ".dlc_with_extended_brand_and_status_mno_tcr_tier",
    "DlcWithExtendedBrandAndStatusOptions": ".dlc_with_extended_brand_and_status_options",
    "DlcWithExtendedBrandAndStatusUseCase": ".dlc_with_extended_brand_and_status_use_case",
    "EnhancedContact": ".enhanced_contact",
    "EnhancedContactItem": ".enhanced_contact_item",
    "Error": ".error",
    "ExtendedBrand": ".extended_brand",
    "ExtendedBrandWithVetting": ".extended_brand_with_vetting",
    "ExtendedRcsCampaign": ".extended_rcs_campaign",
    "GetConversationParams": ".get_conversation_params",
    "GetDlcCampaignStatusResponseUpdates": ".get_dlc_campaign_status_response_updates",
    "GetTollFreeCampaignStatusResponseUpdates": ".get_toll_free_campaign_status_response_updates",
    "LinkClickEvent": ".link_click_event",
    "LocationShareAction": ".location_share_action",
    "LocationShareActionData": ".location_share_action_data",
    "Message": ".message",
    "MessageContent": ".message_content",
    "MessageEvent": ".message_event",
    "MessageEventContent": ".message_event_content",
    "MessageEventConversation": ".message_event_conversation",
    "MessageEventDirection": ".message_event_direction",
    "MessageEventMmsContent": ".message_event_mms_content",
    "MessageEventRcsButtonData": ".message_event_rcs_button_data",
    "MessageEventRcsCardsContent": ".message_event_rcs_cards_content",
    "MessageEventRcsCardsContentCardsItem": ".message_event_rcs_cards_content_cards_item",
    "MessageEventRcsLocationData": ".message_event_rcs_location_data",
    "MessageEventRcsMediaContent": ".message_event_rcs_media_content",
    "MessageEventRcsTextContent": ".message_event_rcs_text_content",
    "MessageEventSmsContent": ".message_event_sms_content",
    "MessageList": ".message_list",
    "MessageMethodEnum": ".message_method_enum",
    "MessageProtocolEnum": ".message_protocol_enum",
    "MessageSchedule": ".message_schedule",
    "MessageStatusEnum": ".message_status_enum",
    "MessageVolumeEnum": ".message_volume_enum",
    "MessageWithReaction": ".message_with_reaction",
    "MessageWithReactionDirection": ".message_with_reaction_direction",
    "MessagingProfileEnum": ".messaging_profile_enum",
    "MmsContent": ".mms_content",
    "MmsValidationResponseSegments": ".mms_validation_response_segments",
    "MmsValidationResponseSegmentsValueItem": ".mms_validation_response_segments_value_item",
    "MmsValidationResult": ".mms_validation_result",
    "NotFoundErrorBody": ".not_found_error_body",
    "NumberFormat": ".number_format",
    "OptInMethodEnum": ".opt_in_method_enum",
    "OptionalBrandInfo": ".optional_brand_info",
    "OptionalContact": ".optional_contact",
    "OptionalContacts": ".optional_contacts",
    "Pagination": ".pagination",
    "Phone": ".phone",
    "PhoneCapabilities": ".phone_capabilities",
    "PhoneEnum": ".phone_enum",
    "PhoneFeatureEnum": ".phone_feature_enum",
    "PhoneNumberCampaignAttachFailedItem": ".phone_number_campaign_attach_failed_item",
    "PhoneNumberCampaignAttachPhoneNumbersItem": ".phone_number_campaign_attach_phone_numbers_item",
    "PhoneNumberCampaignAttachPhoneNumbersItemCampaign": ".phone_number_campaign_attach_phone_numbers_item_campaign",
    "PhoneNumberCampaignDetachFailedItem": ".phone_number_campaign_detach_failed_item",
    "PhoneNumberCampaignDetachPhoneNumbersItem": ".phone_number_campaign_detach_phone_numbers_item",
    "PhoneNumberCampaignDetachPhoneNumbersItemCampaign": ".phone_number_campaign_detach_phone_numbers_item_campaign",
    "PhoneNumberCost": ".phone_number_cost",
    "PhoneNumberDetails": ".phone_number_details",
    "PhoneNumberEnum": ".phone_number_enum",
    "PhoneNumberRegion": ".phone_number_region",
    "PhoneNumberStatus": ".phone_number_status",
    "PhoneNumberStatusEnum": ".phone_number_status_enum",
    "PinnacleFileUploadMetadata": ".pinnacle_file_upload_metadata",
    "PinnacleUrlConfig": ".pinnacle_url_config",
    "ProfileStatusEnum": ".profile_status_enum",
    "PurchasedNumber": ".purchased_number",
    "RcsButtonCall": ".rcs_button_call",
    "RcsButtonOpenUrl": ".rcs_button_open_url",
    "RcsButtonOpenUrlWebviewMode": ".rcs_button_open_url_webview_mode",
    "RcsButtonRequestUserLocation": ".rcs_button_request_user_location",
    "RcsButtonScheduleEvent": ".rcs_button_schedule_event",
    "RcsButtonSendLocation": ".rcs_button_send_location",
    "RcsButtonSendLocationLatLong": ".rcs_button_send_location_lat_long",
    "RcsButtonTrigger": ".rcs_button_trigger",
    "RcsCampaign": ".rcs_campaign",
    "RcsCampaignSchemaAgent": ".rcs_campaign_schema_agent",
    "RcsCampaignSchemaAgentEmailsItem": ".rcs_campaign_schema_agent_emails_item",
    "RcsCampaignSchemaAgentPhonesItem": ".rcs_campaign_schema_agent_phones_item",
    "RcsCampaignSchemaAgentWebsitesItem": ".rcs_campaign_schema_agent_websites_item",
    "RcsCampaignSchemaExtraAgent": ".rcs_campaign_schema_extra_agent",
    "RcsCampaignSchemaExtraAgentEmailsItem": ".rcs_campaign_schema_extra_agent_emails_item",
    "RcsCampaignSchemaExtraAgentPhonesItem": ".rcs_campaign_schema_extra_agent_phones_item",
    "RcsCampaignSchemaExtraAgentWebsitesItem": ".rcs_campaign_schema_extra_agent_websites_item",
    "RcsCampaignSchemaExtraKeywords": ".rcs_campaign_schema_extra_keywords",
    "RcsCampaignSchemaExtraKeywordsHelp": ".rcs_campaign_schema_extra_keywords_help",
    "RcsCampaignSchemaExtraKeywordsOptIn": ".rcs_campaign_schema_extra_keywords_opt_in",
    "RcsCampaignSchemaExtraKeywordsOptOut": ".rcs_campaign_schema_extra_keywords_opt_out",
    "RcsCampaignSchemaExtraLinks": ".rcs_campaign_schema_extra_links",
    "RcsCampaignSchemaExtraTraffic": ".rcs_campaign_schema_extra_traffic",
    "RcsCampaignSchemaExtraUseCase": ".rcs_campaign_schema_extra_use_case",
    "RcsCampaignSchemaKeywords": ".rcs_campaign_schema_keywords",
    "RcsCampaignSchemaKeywordsHelp": ".rcs_campaign_schema_keywords_help",
    "RcsCampaignSchemaKeywordsOptIn": ".rcs_campaign_schema_keywords_opt_in",
    "RcsCampaignSchemaKeywordsOptOut": ".rcs_campaign_schema_keywords_opt_out",
    "RcsCampaignSchemaLinks": ".rcs_campaign_schema_links",
    "RcsCampaignSchemaTraffic": ".rcs_campaign_schema_traffic",
    "RcsCampaignSchemaUseCase": ".rcs_campaign_schema_use_case",
    "RcsCampaignStatus": ".rcs_campaign_status",
    "RcsCampaignUseCaseEnum": ".rcs_campaign_use_case_enum",
    "RcsCapabilitiesResult": ".rcs_capabilities_result",
    "RcsCapability": ".rcs_capability",
    "RcsCapabilityActions": ".rcs_capability_actions",
    "RcsCapabilityCards": ".rcs_capability_cards",
    "RcsCardsContent": ".rcs_cards_content",
    "RcsCardsContentCardsItem": ".rcs_cards_content_cards_item",
    "RcsContent": ".rcs_content",
    "RcsLinkResult": ".rcs_link_result",
    "RcsMediaContent": ".rcs_media_content",
    "RcsMediaDetailsContent": ".rcs_media_details_content",
    "RcsMessagingTypeEnum": ".rcs_messaging_type_enum",
    "RcsValidateContent": ".rcs_validate_content",
    "RcsValidateContentMedia": ".rcs_validate_content_media",
    "RcsValidationResult": ".rcs_validation_result",
    "RcsWhitelistResponse": ".rcs_whitelist_response",
    "ReactionResult": ".reaction_result",
    "RefreshedFile": ".refreshed_file",
    "RichButton": ".rich_button",
    "RichButton_Call": ".rich_button",
    "RichButton_OpenUrl": ".rich_button",
    "RichButton_RequestUserLocation": ".rich_button",
    "RichButton_ScheduleEvent": ".rich_button",
    "RichButton_SendLocation": ".rich_button",
    "RichButton_Trigger": ".rich_button",
    "RichCard": ".rich_card",
    "RichCards": ".rich_cards",
    "RichCardsMessage": ".rich_cards_message",
    "RichMediaMessage": ".rich_media_message",
    "RichMessage": ".rich_message",
    "RichStandaloneCardOptions": ".rich_standalone_card_options",
    "RichText": ".rich_text",
    "RichTextMessage": ".rich_text_message",
    "ScheduleCancelResult": ".schedule_cancel_result",
    "ScheduledBlastDetails": ".scheduled_blast_details",
    "ScheduledBlastResponseConfig": ".scheduled_blast_response_config",
    "ScheduledMessage": ".scheduled_message",
    "ScheduledSendResponseConfig": ".scheduled_send_response_config",
    "SendRcsCardOptionsStandaloneCardImageAlignment": ".send_rcs_card_options_standalone_card_image_alignment",
    "SendRcsCardOptionsStandaloneCardOrientation": ".send_rcs_card_options_standalone_card_orientation",
    "SendRichCardsOptions": ".send_rich_cards_options",
    "SendRichMessageOptions": ".send_rich_message_options",
    "SendSmsResponseSegments": ".send_sms_response_segments",
    "SendSmsResponseSegmentsEncoding": ".send_sms_response_segments_encoding",
    "SendTypingIndicatorResponse": ".send_typing_indicator_response",
    "Sender": ".sender",
    "SentMmsDetails": ".sent_mms_details",
    "SentRichMessage": ".sent_rich_message",
    "SentSmsDetails": ".sent_sms_details",
    "ShortenedUrl": ".shortened_url",
    "ShortenedUrlWithClickData": ".shortened_url_with_click_data",
    "SmsContent": ".sms_content",
    "SmsValidationResponseSegments": ".sms_validation_response_segments",
    "SmsValidationResponseSegmentsGsm7": ".sms_validation_response_segments_gsm_7",
    "SmsValidationResponseSegmentsUtf16": ".sms_validation_response_segments_utf_16",
    "SmsValidationResponseTotal": ".sms_validation_response_total",
    "SmsValidationResult": ".sms_validation_result",
    "SubUseCaseEnum": ".sub_use_case_enum",
    "SubmissionResults": ".submission_results",
    "SuccessfulConversationUpdate": ".successful_conversation_update",
    "TollFreeCampaign": ".toll_free_campaign",
    "TollFreeCampaignSchemaKeywords": ".toll_free_campaign_schema_keywords",
    "TollFreeCampaignSchemaKeywordsHelp": ".toll_free_campaign_schema_keywords_help",
    "TollFreeCampaignSchemaKeywordsOptIn": ".toll_free_campaign_schema_keywords_opt_in",
    "TollFreeCampaignSchemaLinks": ".toll_free_campaign_schema_links",
    "TollFreeCampaignSchemaOptIn": ".toll_free_campaign_schema_opt_in",
    "TollFreeCampaignSchemaOptions": ".toll_free_campaign_schema_options",
    "TollFreeCampaignSchemaUseCase": ".toll_free_campaign_schema_use_case",
    "TollFreeCampaignStatus": ".toll_free_campaign_status",
    "TollFreeCampaignUseCaseEnum": ".toll_free_campaign_use_case_enum",
    "TollFreeCampaignWithExtendedBrandAndStatus": ".toll_free_campaign_with_extended_brand_and_status",
    "TollFreeStatusEnum": ".toll_free_status_enum",
    "TollFreeWithExtendedBrandAndStatusKeywords": ".toll_free_with_extended_brand_and_status_keywords",
    "TollFreeWithExtendedBrandAndStatusKeywordsHelp": ".toll_free_with_extended_brand_and_status_keywords_help",
    "TollFreeWithExtendedBrandAndStatusKeywordsOptIn": ".toll_free_with_extended_brand_and_status_keywords_opt_in",
    "TollFreeWithExtendedBrandAndStatusLinks": ".toll_free_with_extended_brand_and_status_links",
    "TollFreeWithExtendedBrandAndStatusOptIn": ".toll_free_with_extended_brand_and_status_opt_in",
    "TollFreeWithExtendedBrandAndStatusOptions": ".toll_free_with_extended_brand_and_status_options",
    "TollFreeWithExtendedBrandAndStatusUseCase": ".toll_free_with_extended_brand_and_status_use_case",
    "Tracking": ".tracking",
    "UpdatedContactId": ".updated_contact_id",
    "UploadResults": ".upload_results",
    "UserEvent": ".user_event",
    "UserEventConversation": ".user_event_conversation",
    "VCardAddressSchemaTypeItem": ".v_card_address_schema_type_item",
    "VCardData": ".v_card_data",
    "VCardDataFile": ".v_card_data_file",
    "VCardDataFileMetadata": ".v_card_data_file_metadata",
    "VCardEmailSchemaTypeItem": ".v_card_email_schema_type_item",
    "VCardGeo": ".v_card_geo",
    "VCardName": ".v_card_name",
    "VCardOrganization": ".v_card_organization",
    "VCardPhoneSchemaTypeItem": ".v_card_phone_schema_type_item",
    "ValidateCampaignParams": ".validate_campaign_params",
    "ValidationErrorDetails": ".validation_error_details",
    "ValidationResults": ".validation_results",
    "Vcard": ".vcard",
    "VcardAddress": ".vcard_address",
    "VcardContent": ".vcard_content",
    "VcardEmail": ".vcard_email",
    "VcardPhone": ".vcard_phone",
    "VcardResource": ".vcard_resource",
    "VettingFeedback": ".vetting_feedback",
    "VettingHistory": ".vetting_history",
    "VettingHistoryVettingStatus": ".vetting_history_vetting_status",
    "VettingResults": ".vetting_results",
    "WebhookEventEnum": ".webhook_event_enum",
    "WebhookResult": ".webhook_result",
    "Webhooks": ".webhooks",
    "ZodError": ".zod_error",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AdvancedPhoneInformation",
    "AdvancedPhoneInformationCarrier",
    "AdvancedPhoneInformationContact",
    "AdvancedPhoneInformationLocation",
    "AdvancedPhoneInformationLocationCoordinates",
    "AdvancedPhoneInformationLocationCountry",
    "AdvancedPhoneInformationType",
    "AdvancedPhoneInformationTypeRecommendation",
    "Agent",
    "AttachWebhookByIdParams",
    "AttachWebhookParams",
    "AttachWebhookResponseWebhook",
    "AttachedPhoneNumberResult",
    "AudienceCountOnly",
    "AudienceWithPagination",
    "AutofillCampaignParams",
    "AutofillDlcCampaignResponse",
    "AutofillDlcResponseKeywords",
    "AutofillDlcResponseKeywordsHelp",
    "AutofillDlcResponseKeywordsOptIn",
    "AutofillDlcResponseKeywordsOptOut",
    "AutofillDlcResponseLinks",
    "AutofillDlcResponseOptions",
    "AutofillDlcResponseUseCase",
    "BadRequestErrorBody",
    "BaseRichMessage",
    "BasicPhoneInformation",
    "BasicPhoneInformationContact",
    "BasicPhoneInformationLocation",
    "BasicPhoneInformationLocationCountry",
    "BlastDetails",
    "BrandStatus",
    "BrandStatusEnum",
    "ButtonClicked",
    "ButtonClickedData",
    "ButtonClickedDataButton",
    "ButtonClickedDataButtonRaw",
    "ButtonClickedDataButtonType",
    "BuyResponseCapabilities",
    "CampaignEnum",
    "CampaignQuery",
    "CampaignSubmissionResult",
    "CampaignValidationResponseErrorsItem",
    "CampaignValidationResult",
    "CompanyEntityTypeEnum",
    "CompanySectorEnum",
    "CompanyTypeEnum",
    "ConfiguredWebhook",
    "Contact",
    "ContactId",
    "Conversation",
    "ConversationByIdParams",
    "ConversationByParticipantsParams",
    "ConversationContact",
    "ConversationList",
    "ConversationSender",
    "CreateAndAttachWebhookByUrlParams",
    "CreateUrlOptions",
    "DeleteAudienceResponse",
    "DetachedPhoneNumberResult",
    "DetachedWebhookInfo",
    "DetailedPhoneNumberEnum",
    "DlcAssignmentStatusEnum",
    "DlcCampaignStatus",
    "DlcCampaignUseCaseEnum",
    "DlcCampaignWithExtendedBrandAndStatus",
    "DlcWithExtendedBrandAndStatusKeywords",
    "DlcWithExtendedBrandAndStatusKeywordsHelp",
    "DlcWithExtendedBrandAndStatusKeywordsOptIn",
    "DlcWithExtendedBrandAndStatusKeywordsOptOut",
    "DlcWithExtendedBrandAndStatusLinks",
    "DlcWithExtendedBrandAndStatusMnoBrandTier",
    "DlcWithExtendedBrandAndStatusMnoTcrTier",
    "DlcWithExtendedBrandAndStatusOptions",
    "DlcWithExtendedBrandAndStatusUseCase",
    "EnhancedContact",
    "EnhancedContactItem",
    "Error",
    "ExtendedBrand",
    "ExtendedBrandWithVetting",
    "ExtendedRcsCampaign",
    "GetConversationParams",
    "GetDlcCampaignStatusResponseUpdates",
    "GetTollFreeCampaignStatusResponseUpdates",
    "LinkClickEvent",
    "LocationShareAction",
    "LocationShareActionData",
    "Message",
    "MessageContent",
    "MessageEvent",
    "MessageEventContent",
    "MessageEventConversation",
    "MessageEventDirection",
    "MessageEventMmsContent",
    "MessageEventRcsButtonData",
    "MessageEventRcsCardsContent",
    "MessageEventRcsCardsContentCardsItem",
    "MessageEventRcsLocationData",
    "MessageEventRcsMediaContent",
    "MessageEventRcsTextContent",
    "MessageEventSmsContent",
    "MessageList",
    "MessageMethodEnum",
    "MessageProtocolEnum",
    "MessageSchedule",
    "MessageStatusEnum",
    "MessageVolumeEnum",
    "MessageWithReaction",
    "MessageWithReactionDirection",
    "MessagingProfileEnum",
    "MmsContent",
    "MmsValidationResponseSegments",
    "MmsValidationResponseSegmentsValueItem",
    "MmsValidationResult",
    "NotFoundErrorBody",
    "NumberFormat",
    "OptInMethodEnum",
    "OptionalBrandInfo",
    "OptionalContact",
    "OptionalContacts",
    "Pagination",
    "Phone",
    "PhoneCapabilities",
    "PhoneEnum",
    "PhoneFeatureEnum",
    "PhoneNumberCampaignAttachFailedItem",
    "PhoneNumberCampaignAttachPhoneNumbersItem",
    "PhoneNumberCampaignAttachPhoneNumbersItemCampaign",
    "PhoneNumberCampaignDetachFailedItem",
    "PhoneNumberCampaignDetachPhoneNumbersItem",
    "PhoneNumberCampaignDetachPhoneNumbersItemCampaign",
    "PhoneNumberCost",
    "PhoneNumberDetails",
    "PhoneNumberEnum",
    "PhoneNumberRegion",
    "PhoneNumberStatus",
    "PhoneNumberStatusEnum",
    "PinnacleFileUploadMetadata",
    "PinnacleUrlConfig",
    "ProfileStatusEnum",
    "PurchasedNumber",
    "RcsButtonCall",
    "RcsButtonOpenUrl",
    "RcsButtonOpenUrlWebviewMode",
    "RcsButtonRequestUserLocation",
    "RcsButtonScheduleEvent",
    "RcsButtonSendLocation",
    "RcsButtonSendLocationLatLong",
    "RcsButtonTrigger",
    "RcsCampaign",
    "RcsCampaignSchemaAgent",
    "RcsCampaignSchemaAgentEmailsItem",
    "RcsCampaignSchemaAgentPhonesItem",
    "RcsCampaignSchemaAgentWebsitesItem",
    "RcsCampaignSchemaExtraAgent",
    "RcsCampaignSchemaExtraAgentEmailsItem",
    "RcsCampaignSchemaExtraAgentPhonesItem",
    "RcsCampaignSchemaExtraAgentWebsitesItem",
    "RcsCampaignSchemaExtraKeywords",
    "RcsCampaignSchemaExtraKeywordsHelp",
    "RcsCampaignSchemaExtraKeywordsOptIn",
    "RcsCampaignSchemaExtraKeywordsOptOut",
    "RcsCampaignSchemaExtraLinks",
    "RcsCampaignSchemaExtraTraffic",
    "RcsCampaignSchemaExtraUseCase",
    "RcsCampaignSchemaKeywords",
    "RcsCampaignSchemaKeywordsHelp",
    "RcsCampaignSchemaKeywordsOptIn",
    "RcsCampaignSchemaKeywordsOptOut",
    "RcsCampaignSchemaLinks",
    "RcsCampaignSchemaTraffic",
    "RcsCampaignSchemaUseCase",
    "RcsCampaignStatus",
    "RcsCampaignUseCaseEnum",
    "RcsCapabilitiesResult",
    "RcsCapability",
    "RcsCapabilityActions",
    "RcsCapabilityCards",
    "RcsCardsContent",
    "RcsCardsContentCardsItem",
    "RcsContent",
    "RcsLinkResult",
    "RcsMediaContent",
    "RcsMediaDetailsContent",
    "RcsMessagingTypeEnum",
    "RcsValidateContent",
    "RcsValidateContentMedia",
    "RcsValidationResult",
    "RcsWhitelistResponse",
    "ReactionResult",
    "RefreshedFile",
    "RichButton",
    "RichButton_Call",
    "RichButton_OpenUrl",
    "RichButton_RequestUserLocation",
    "RichButton_ScheduleEvent",
    "RichButton_SendLocation",
    "RichButton_Trigger",
    "RichCard",
    "RichCards",
    "RichCardsMessage",
    "RichMediaMessage",
    "RichMessage",
    "RichStandaloneCardOptions",
    "RichText",
    "RichTextMessage",
    "ScheduleCancelResult",
    "ScheduledBlastDetails",
    "ScheduledBlastResponseConfig",
    "ScheduledMessage",
    "ScheduledSendResponseConfig",
    "SendRcsCardOptionsStandaloneCardImageAlignment",
    "SendRcsCardOptionsStandaloneCardOrientation",
    "SendRichCardsOptions",
    "SendRichMessageOptions",
    "SendSmsResponseSegments",
    "SendSmsResponseSegmentsEncoding",
    "SendTypingIndicatorResponse",
    "Sender",
    "SentMmsDetails",
    "SentRichMessage",
    "SentSmsDetails",
    "ShortenedUrl",
    "ShortenedUrlWithClickData",
    "SmsContent",
    "SmsValidationResponseSegments",
    "SmsValidationResponseSegmentsGsm7",
    "SmsValidationResponseSegmentsUtf16",
    "SmsValidationResponseTotal",
    "SmsValidationResult",
    "SubUseCaseEnum",
    "SubmissionResults",
    "SuccessfulConversationUpdate",
    "TollFreeCampaign",
    "TollFreeCampaignSchemaKeywords",
    "TollFreeCampaignSchemaKeywordsHelp",
    "TollFreeCampaignSchemaKeywordsOptIn",
    "TollFreeCampaignSchemaLinks",
    "TollFreeCampaignSchemaOptIn",
    "TollFreeCampaignSchemaOptions",
    "TollFreeCampaignSchemaUseCase",
    "TollFreeCampaignStatus",
    "TollFreeCampaignUseCaseEnum",
    "TollFreeCampaignWithExtendedBrandAndStatus",
    "TollFreeStatusEnum",
    "TollFreeWithExtendedBrandAndStatusKeywords",
    "TollFreeWithExtendedBrandAndStatusKeywordsHelp",
    "TollFreeWithExtendedBrandAndStatusKeywordsOptIn",
    "TollFreeWithExtendedBrandAndStatusLinks",
    "TollFreeWithExtendedBrandAndStatusOptIn",
    "TollFreeWithExtendedBrandAndStatusOptions",
    "TollFreeWithExtendedBrandAndStatusUseCase",
    "Tracking",
    "UpdatedContactId",
    "UploadResults",
    "UserEvent",
    "UserEventConversation",
    "VCardAddressSchemaTypeItem",
    "VCardData",
    "VCardDataFile",
    "VCardDataFileMetadata",
    "VCardEmailSchemaTypeItem",
    "VCardGeo",
    "VCardName",
    "VCardOrganization",
    "VCardPhoneSchemaTypeItem",
    "ValidateCampaignParams",
    "ValidationErrorDetails",
    "ValidationResults",
    "Vcard",
    "VcardAddress",
    "VcardContent",
    "VcardEmail",
    "VcardPhone",
    "VcardResource",
    "VettingFeedback",
    "VettingHistory",
    "VettingHistoryVettingStatus",
    "VettingResults",
    "WebhookEventEnum",
    "WebhookResult",
    "Webhooks",
    "ZodError",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class SearchPhoneNumberByDigits(UniversalBaseModel):
    """
    Filter your search by digit pattern.
    """

    contains: typing.Optional[str] = pydantic.Field(default=None)
    """
    Your search will return only numbers that contain this digit sequence anywhere within them.
    """

    ends_with: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="endsWith")] = pydantic.Field(
        default=None
    )
    """
    Your search will return only numbers that end with these digits.
    """

    starts_with: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="startsWith")] = pydantic.Field(
        default=None
    )
    """
    Your search will return only numbers that begin with these digits.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class PhoneCapabilities(UniversalBaseModel):
    """
    Represents the communication capabilities available for a phone number.
    """

    mms: bool = pydantic.Field()
    """
    Whether the phone number supports MMS (multimedia messaging).
    """

    sms: bool = pydantic.Field()
    """
    Whether the phone number supports SMS messaging.
    """

    voice: bool = pydantic.Field()
    """
    Whether the phone number supports voice calls.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .button_clicked_data import ButtonClickedData


class MessageEventRcsButtonData(ButtonClickedData):
    """
    Button click event data received when a user clicks on an RCS button or quick reply (excluding `requestUserLocation` buttons).

    This event contains information about which button was clicked, how many times it's been clicked, and any payload or metadata attached to the button. Use this data to handle user interactions with your RCS messages.
    """

    type: typing.Literal["RCS_BUTTON_DATA"] = pydantic.Field(default="RCS_BUTTON_DATA")
    """
    Message type identifier.
    """

    id: str = pydantic.Field()
    """
    Unique identifier of the message. This identifier is a string that always begins with the prefix `msg_`, for example: `msg_1234567890`. <br><br>
    To get the message details, use the [GET /messages/{id}](/api-reference/messages/get) endpoint.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
